@@ -1579,11 +1579,8 @@ function collapse_multifields(params0) {
         if (queue_type != 'default') {
             params['arguments']['x-queue-type'] = queue_type;
         }
-        if (queue_type == 'quorum' ||
-            queue_type == 'stream') {
-            params['durable'] = true;
-            params['auto_delete'] = false;
-        }
+
+        params = Object.assign(params, QUEUE_TYPE[queue_type].params)
     }
     return params;
 }
@@ -1760,8 +1757,19 @@ function select_queue_type(queuetype) {
     update();
 }
 
+function is_internal(queue) {
+    return queue.internal;
+}
+
 function get_queue_type (queue) {    
-    return queue.type;
+    switch(queue.type) {
+        case "classic":
+        case "quorum":
+        case "stream":
+            return queue.type;
+        default:
+            return "default"
+    }
 }
 
 function is_quorum(queue) {
